window.Gleam.initSearch([{"doc":"fmglee","title":"fmglee","content":"# FMglee\n\n[![Package Version](https://img.shields.io/hexpm/v/fmglee)](https://hex.pm/packages/fmglee)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/fmglee/)\n\nFMGlee is a simple string formatting library. It exposes two main APIs to format \nstrings, one driven by pipes, and the other more inline.\n\n```sh\ngleam add fmglee\n```\n```gleam\nimport fmglee\nimport gleeunit/should\n\nfmglee.new(&quot;Number %d, float %f, string %s&quot;)\n|&gt; fmglee.d(99)\n|&gt; fmglee.f(12.9)\n|&gt; fmglee.s(&quot;Hello!&quot;)\n|&gt; fmglee.build\n|&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n\n// OR\n\nfmglee.fmt(&quot;Number %d, float %f, string %s&quot;, with: [fmglee.D(99), fmglee.F(12.9), fmglee.S(&quot;Hello!&quot;)])\n|&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n```\n\nFloat numbers can be rounded, and delimited using the following specifier options (examples use this input 1234.5678).\n- &quot;%.2f&quot; -&gt; Rounds the float to two decimal places - &quot;1234.56&quot;\n- &quot;%.0f&quot; -&gt; Rounds the float to zero decimal places - &quot;1234&quot;\n- &quot;%,f&quot; -&gt; Formats large floats with a comma delimiter - &quot;1,234.5678&quot;\n- &quot;%-.2f&quot; -&gt; Formats the float with a hyphen delimiter and rounds to two decimal places - &quot;1-234.56&quot;\n\nFurther documentation can be found at &lt;https://hexdocs.pm/fmglee&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"fmglee","title":"Fmt","content":"pub type Fmt {\n  S(String)\n  D(Int)\n  F(Float)\n}\n\nS(String)\n Wrap a `String` for use with `sprintf(_, using: [..])`\n\nD(Int)\n Wrap an `Int` for use with `sprintf(_, using: [..])`\n\nF(Float)\n Wrap a `Float` for use with `fmt(_, using: [..])`\n\nSynonyms:\nfmglee.Fmt\nfmglee Fmt","url":"fmglee.html#Fmt"},{"doc":"fmglee","title":"FmtError","content":"pub type FmtError {\n  IncorrectValueType(expected: String, got: Fmt)\n  TooManyValues\n  NotEnoughValues\n  InvalidFloat(String)\n  InvalidInt(String)\n  InvalidFloatFormatSpecifier(String)\n}\n Errors returned by fmtglee\nIncorrectValueType(expected: String, got: Fmt)\n The current value does not match the current placeholder.\n Returned when the order of `Fmt`s is not the same as the order\n of placeholders.\n\nTooManyValues\n Returned when there are more `Fmt`s than placeholders in the string.\n\nNotEnoughValues\n Returned when there are less `Fmt`s than placeholders in the string.\n\nInvalidFloat(String)\n Returned when a number has no floating point.\n\nInvalidInt(String)\n Returned when an invalid Integer value is provided to a Float formatter.\n\nInvalidFloatFormatSpecifier(String)\n Returned when a float format specifier cannot be parsed.\n Can also occur when a `Float` value is provided alongside a `String`\n or `Int` placeholder.\n\nSynonyms:\nfmglee.FmtError\nfmglee FmtError","url":"fmglee.html#FmtError"},{"doc":"fmglee","title":"Formatter","content":"pub opaque type Formatter\n\n\nSynonyms:\nfmglee.Formatter\nfmglee Formatter","url":"fmglee.html#Formatter"},{"doc":"fmglee","title":"build","content":"pub fn build(formatter: Formatter) -&gt; String\n Compile a Formatter into a string. Panics where \n `try_build(formatter)` returns an `FmtError`.\nSynonyms:\nfmglee.build\nfmglee build","url":"fmglee.html#build"},{"doc":"fmglee","title":"d","content":"pub fn d(formatter: Formatter, d: Int) -&gt; Formatter\n Add an `Int` value to a `Formatter`.\nSynonyms:\nfmglee.d\nfmglee d","url":"fmglee.html#d"},{"doc":"fmglee","title":"f","content":"pub fn f(formatter: Formatter, f: Float) -&gt; Formatter\n Add a `Float` value to a `Formatter`.\nSynonyms:\nfmglee.f\nfmglee f","url":"fmglee.html#f"},{"doc":"fmglee","title":"new","content":"pub fn new(s: String) -&gt; Formatter\n Create a new `Formatter`.\n # Examples\n \n new(&quot;Hello, %s. You are %d years old.&quot;)\n |&gt; s(name)\n |&gt; d(age)\n |&gt; build\n \n new(&quot;Hello, %s. You are %d years old.&quot;)\n |&gt; s(name)\n |&gt; d(age)\n |&gt; printlnf\n \nSynonyms:\nfmglee.new\nfmglee new","url":"fmglee.html#new"},{"doc":"fmglee","title":"print","content":"pub fn print(s: String, with v: List(Fmt)) -&gt; Nil\n Compile the format string and print the output.\n Panics if `sprintf(s, v)` would panic with the\n provided arguments.\nSynonyms:\nfmglee.print\nfmglee print","url":"fmglee.html#print"},{"doc":"fmglee","title":"printf","content":"pub fn printf(formatter: Formatter) -&gt; Nil\n Print the output of a compiled `Formatter`.\n Panics if the `Formatter` is invalid.\nSynonyms:\nfmglee.printf\nfmglee printf","url":"fmglee.html#printf"},{"doc":"fmglee","title":"println","content":"pub fn println(s: String, with v: List(Fmt)) -&gt; Nil\n Compile the format string and print the output\n with a newline. Panics if `sprintf(s, v)` would\n panic with the provided arguments.\nSynonyms:\nfmglee.println\nfmglee println","url":"fmglee.html#println"},{"doc":"fmglee","title":"printlnf","content":"pub fn printlnf(formatter: Formatter) -&gt; Nil\n Print the output of a compiled `Formatter`\n with a newline. Panics if the `Formatter`\n is invalid.\nSynonyms:\nfmglee.printlnf\nfmglee printlnf","url":"fmglee.html#printlnf"},{"doc":"fmglee","title":"s","content":"pub fn s(formatter: Formatter, s: String) -&gt; Formatter\n Add a `String` value to a `Formatter`.\nSynonyms:\nfmglee.s\nfmglee s","url":"fmglee.html#s"},{"doc":"fmglee","title":"sprintf","content":"pub fn sprintf(s: String, with v: List(Fmt)) -&gt; String\n Format a string and a list of `Fmt` values.\n Will panic where `try_sprintf(s, v)` returns an\n `FmtError`.\nSynonyms:\nfmglee.sprintf\nfmglee sprintf","url":"fmglee.html#sprintf"},{"doc":"fmglee","title":"try_build","content":"pub fn try_build(\n  formatter: Formatter,\n) -&gt; Result(String, FmtError)\n Compile a `Formatter` into a string. Errors when the\n number of provided values does not match the number\n of placeholders, or if an invalid type was provided\n for a placeholder.\nSynonyms:\nfmglee.try_build\nfmglee try_build","url":"fmglee.html#try_build"},{"doc":"fmglee","title":"try_sprintf","content":"pub fn try_sprintf(\n  s: String,\n  with v: List(Fmt),\n) -&gt; Result(String, FmtError)\n Format a string and a list of `Fmt` values. Substitutes\n placeholders from left to right with values in the\n list of Fmt. Errors if there is a type mismatch between\n the placeholder and the value, or if the number of placeholders\n does not match the number of values given.\nSynonyms:\nfmglee.try_sprintf\nfmglee try_sprintf","url":"fmglee.html#try_sprintf"},{"doc":"fmglee","title":"try_write","content":"pub fn try_write(\n  s: String,\n  with v: List(Fmt),\n  using writer: fn(String) -&gt; a,\n) -&gt; Result(a, FmtError)\n Write a string and a list of `Fmt` to the provided `Writer`.\n Errors when the format string is incompatible with the provided\n `Fmt` values.\nSynonyms:\nfmglee.try_write\nfmglee try_write","url":"fmglee.html#try_write"},{"doc":"fmglee","title":"try_writef","content":"pub fn try_writef(\n  formatter: Formatter,\n  using writer: fn(String) -&gt; a,\n) -&gt; Result(a, FmtError)\n Writer a `Formatter` to the provided writer. The `Formatter`\n will be built using `try_sprintf` which will error if the\n formatter is invalid.\nSynonyms:\nfmglee.try_writef\nfmglee try_writef","url":"fmglee.html#try_writef"},{"doc":"fmglee","title":"write","content":"pub fn write(\n  s: String,\n  with v: List(Fmt),\n  using writer: fn(String) -&gt; a,\n) -&gt; a\n Write a string and list of `Fmt` to the provided `Writer`.\nSynonyms:\nfmglee.write\nfmglee write","url":"fmglee.html#write"},{"doc":"fmglee","title":"writef","content":"pub fn writef(\n  formatter: Formatter,\n  using writer: fn(String) -&gt; a,\n) -&gt; a\n Write a `Formatter` to the provided writer. The `Formatter`\n will be built using `sprintf` which will panic if the\n formatter is invalid.\nSynonyms:\nfmglee.writef\nfmglee writef","url":"fmglee.html#writef"},{"doc":"fmglee","title":"fmglee","content":" # fmglee\n\n A string formatting library for gleam.\n\n Valid format specifiers are\n - %s - String\n - %d - Int\n - %f - Float\n\n Examples\n ```gleam\n import fmglee\n import gleeunit/should\n \n fmglee.new(&quot;Number %d, float %f, string %s&quot;)\n |&gt; fmglee.d(99)\n |&gt; fmglee.f(12.9)\n |&gt; fmglee.s(&quot;Hello!&quot;)\n |&gt; fmglee.build\n |&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n ```\n ```gleam\n fmglee.sprintf(&quot;Number %d, float %f, string %s&quot;, with: [fmglee.D(99), fmglee.F(12.9), fmglee.S(&quot;Hello!&quot;)])\n |&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n ```\n ```gleam\n fmglee.sprintf(&quot;%,.2f&quot;, [fmglee.F(1234.554)])\n |&gt; should.equal(&quot;1,234.55&quot;)\n ```","url":"fmglee.html"}]);